#
# spec file for package handbrake
#
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
# Copyright (c) 2014 B1 Systems GmbH, Vobhurg, Germany
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           handbrake
Summary:        Multithreaded Video Transcoder
Version:        0.10.5
Release:        2.46
Url:            http://handbrake.fr/
Source0:        HandBrake-%{version}.tar.bz2
Patch0:         HandBrake-no-builddate.patch
Patch1:         HandBrake-build-shared.patch
Patch3:         HandBrake-ffmpeg3.patch
License:        GPL-2.0+
Group:          Productivity/Multimedia/Video/Editors and Convertors
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cmake
BuildRequires:  curl
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  nasm
BuildRequires:  python > 2.7.3
BuildRequires:  subversion
BuildRequires:  update-desktop-files
BuildRequires:  wget
BuildRequires:  yasm
BuildRequires:  glibc-devel
BuildRequires:  libmp3lame-devel
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(dvdnav)
BuildRequires:  pkgconfig(dvdread)
%if 0%{?suse_version} <= 1140
BuildRequires:  pkgconfig(gstreamer-0.10)
BuildRequires:  pkgconfig(gstreamer-plugins-base-0.10)
BuildRequires:  pkgconfig(liblzma)
%else
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
%endif
%if 0%{?suse_version} >= 1310
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.10
BuildRequires:  pkgconfig(webkitgtk-3.0)
%endif
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(libass)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavresample)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libbluray)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(vpx)
BuildRequires:  pkgconfig(x264)
BuildRequires:  pkgconfig(x265)
%ifarch armv6l || armv6hl
BuildRequires:  Mesa-libEGL1
BuildRequires:  Mesa-libEGL-devel
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
HandBrake is an open-source, GPL-licensed, multiplatform, multithreaded video
transcoder.

%package cli
Summary:        Multithreaded Video Transcoder
Group:          Productivity/Multimedia/Video/Editors and Convertors

%description cli
HandBrake is an open-source, GPL-licensed, multiplatform, multithreaded video
transcoder.

This package contains a command-line interface for Handbrake.

%if 0%{?suse_version} >= 1310
%package gtk
Summary:        Multithreaded Video Transcoder
Group:          Productivity/Multimedia/Video/Editors and Convertors
Recommends:     handbrake-gtk-lang = %{version}-%{release}

%description gtk
HandBrake is an open-source, GPL-licensed, multiplatform, multithreaded video
transcoder.

This package contains a GTK+ graphical user interface for Handbrake.

%lang_package -n handbrake-gtk
%endif

%prep
%setup -q -n HandBrake-%{version}
%patch0 -p0
%patch1 -p0
%patch3 -p1

%build
export CFLAGS="%{optflags} -fno-strict-aliasing -Wno-unused -I%{_includedir}/ffmpeg"
export CXXFLAGS="$CFLAGS -Wno-reorder"
export PATH="%{_builddir}/HandBrake-%{version}/build/contrib/bin:$PATH"

# try to remove build date from binaries... -- seife+obs@b1-systems.com
PKGDATE=$(date -r %{_sourcedir}/handbrake.changes +%Y%m%d)
sed -i -e "s/@BUILD@/$PKGDATE/" make/configure.py

%__mkdir build
./configure \
    --force \
    --build="$PWD/build" \
    --prefix=%{_prefix} \
    --strip="/bin/true" \
    --optimize=speed \
%if 0%{?suse_version} < 1310
    --disable-gtk \
%endif
    --disable-fdk-aac \
    --debug=max

pushd build
%__make libhb/project.h
%__make %{?_smp_mflags}
popd

%install
%makeinstall -C build

%if 0%{?suse_version} >= 1310
%__ln_s ghb %{buildroot}%{_bindir}/HandBrakeGUI

%suse_update_desktop_file -r ghb AudioVideo AudioVideoEditing

# -f because it might not be there if built without gtk...
%__rm -f "%{buildroot}%{_datadir}/icons"/*/*.cache

%find_lang ghb
%endif

%files cli
%defattr(-,root,root)
%doc AUTHORS COPYING CREDITS NEWS THANKS
%{_bindir}/HandBrakeCLI

%if 0%{?suse_version} >= 1310
%files gtk
%defattr(-,root,root)
%doc AUTHORS COPYING CREDITS NEWS THANKS
%{_bindir}/HandBrakeGUI
%{_bindir}/ghb
%{_datadir}/applications/ghb.desktop
%{_datadir}/icons/*/*/apps/hb-icon.*

%files -n handbrake-gtk-lang -f ghb.lang
%endif

%changelog
* Mon Aug 15 2016 olaf@aepfle.de
- Accept any ffmpeg version to fix build in TW and 42.2
* Sat Feb 20 2016 joerg.lorenzen@ki.tng.de
- update to version 0.10.5
  + Removal of FDK AAC from our binary releases, --enable-fdk is
    required for "non-free" builds if compiling from source.
  - Please see out AAC Encoder Change Announcement to understand
    what this means.
  + Updated x265 to 1.9 which brings bug fixes and performance
    improvements.
  + Few minor bug fixes since the 0.10.3 release. This includes
    improvements in large AVI file handling.
- Build against ffmpeg-3.0
- version 0.10.3
  + Various bug fixes for all platforms and the core engine.
  + Updated x265 to 1.8 which brings numerous bug fixes and some
    performance improvements.
* Sat Jan  9 2016 joerg.lorenzen@ki.tng.de
- Removed all 3rd party tarballs and addded HandBrake-build-shared.patch
  to build against shared libraries.
- Disabled fdk-aac because ist's only needed for static build of
  libav/ffmpeg.
- Changed BuildRequires to pkgconfig() where possible and removed
  some unneeded dependencies.
- Enabled build for armv6l.
* Sun Jun 28 2015 seife+obs@b1-systems.com
- update to 0.10.2
  * Assorted bug fixes and performance improvements
* Tue Apr 21 2015 seife+obs@b1-systems.com
- switch to gstreamer-1.0 instead of old gstreamer-0.10 for
  distributions newer than openSUSE 11.4
* Sun Apr 19 2015 seife+obs@b1-systems.com
- update to 0.10.1:
  - various bug fixes for all platforms and the core engine
  - updated x265 to 1.5 which brings numerous bug fixes and some
  performance improvements
- do not buildrequire wget, curl, subversion -- it's not needed
- fix --prefix and DESTDIR usage to avoid build paths in binaries
  and thus unnecessary republishing
* Tue Dec  2 2014 seife+obs@b1-systems.com
- fix "no return in nonvoid function" compiler error from embedded
  libdvdnav libdvdnav-5.0.1-noreturninnonvoidfunction.patch
* Tue Dec  2 2014 seife+obs@b1-systems.com
- adjust debug config from max to std to avoid ffmpeg assert aborts
* Tue Nov 25 2014 seife+obs@b1-systems.com
- update to 0.10.0:
- remove obsolete patches, update support tarballs, only add
  the really needed stuff
- more build date removal
- important change: due to GTK3 version dependencies, the GUI
  is only built for distributions newer than openSUSE 12.3
* Fri Apr 18 2014 seife+obs@b1-systems.com
- remove build date from binaries to avoid republishing
* Sun Dec  1 2013 obs@botter.cc
- add patch to fix compiling libx264: HandBrake-0.9.9_libx264-gcc-488-fix.patch
  add -fno-aggressive-loop-optimizations to extra-cflags in
  configure for >= 13.1, see also
  https://bugs.launchpad.net/ubuntu/+source/x264/+bug/1241772
  MAY BE REMOVED on upstream fix
* Thu Jun 13 2013 dnh@opensuse.org
- update to 0.9.9
  * replace harfbuzz patch by script fragement in spec
  * update yasm, libbluray, x264, replace ffmpeg by libav
  * remove tarballs that can be system-libs
* Sat Apr  6 2013 dnh@opensuse.org
- fix conflicts with harfbuzz headers for oS >= 12.3
  see https://pmbs.links2linux.org/request/show/425
* Sun Oct  7 2012 i@marguerite.su
- update to 0.9.8
  * Corrects a few crash bugs that showed up in 0.9.7
  * Includes an AppleTV3 Preset and updated iPad Preset (0.9.7)
* Thu Mar  1 2012 pascal.bleser@opensuse.org
- update to 0.9.6
* Thu Jul  7 2011 malcolmlewis@opensuse.org
- Add BuildRequires libgudev-1_0-devel as build failing with
  'No package 'gudev-1.0' found' error.
* Tue Jan  4 2011 pascal.bleser@opensuse.org
- update to 0.9.5
* Tue Sep 21 2010 pascal.bleser@opensuse.org
- update to trunk revision 3549:
  * try other gstreamer sink interfaces if gconfvideosink fails; it appears that gconfvideosink may not work on kde systems
  * remove the 8 audio limit
  * fix cli issue with batch scan and encode
  * fix a crash when a TS has no aspect ratio set in the video stream
  * bump ffmpeg from 22950 to 25082
  * fix a rare hang in the muxer
  * GUI: fix UI problem with trellis cavlc
  * add Bluray support:
    + unencrypted BD directory trees only
    + doesn't support iso images
    + also, no PGS subtitle support yet
  * chapters and angles are supported
  * fixes memory leak during scan
  * x264 bump from r1698 to r1713:
    + introduces trellis and psy-trellis for cavlc
  * GUI: simplify source selection dialog
  * fix muxing problem with certain sources/settings
* Thu Aug 19 2010 pascal.bleser@opensuse.org
- update to SVN trunk revision 3482:
  * x264 bump from r1681 to r1698: various bugfixes and improvements
* Sat Aug  7 2010 pascal.bleser@opensuse.org
- update to SVN trunk revision 3473, as requested by upstream
* Fri Nov 27 2009 pascal.bleser@opensuse.org
- update to 0.9.4
* Sun Nov  1 2009 pascal.bleser@opensuse.org
- update to snapshot 2907
* Thu Oct  1 2009 pascal.bleser@opensuse.org
- downgrade to snapshot rev 2845 as per upstream request
- fix version display
- use upstream compiler flags as per upstream request
* Fri Sep 25 2009 pascal.bleser@opensuse.org
- update to rev 2844:
  * [2844] bump libtheora to official 1.1 release
  * [2843] fix srt track stop time; srt stop time was being set to the end of the start chapter instead of the end of the stop chapter
  * [2842] theora: improvements to our theora implementation:
    + support 2-pass mode which is new to theora 1.1
    + set soft target rate control so that single pass abr behaves more like theora 1.0 and doesn't look quite so awful
  * [2841] don't remove srt subs when changing from mkv to mp4
  * [2836] bump x264 to r1271 make changes required by the x264 api change fix some build issues that the x264 bump exposed
  * [2831] fix bug that was causing one sec. of audio to be dropped on many ffmpeg files
* Mon Sep 14 2009 pascal.bleser@opensuse.org
- update to rev 2822:
  * [2821] dvdnav: improved patch that guarantees forward seek moves position forward; the previous patch worked only for SEEK_CUR
  * [2822] allow dvd sources that have no audio
* Sun Sep 13 2009 pascal.bleser@opensuse.org
- update to rev 2815:
  * [2796] set use m4v preference enabled by default
  * [2797] fix PAR issue with DV For some (maybe all) DV, ffmpeg doesn't give us the sample_aspect_ratio in the context; so when it's missing, try looking it up in the AVStream info
  * [2811] improve "auto" audio selection picks the "best" audio given the input codec and output formats
  * [2812] show the correct audio codec in the audio list when it has been changed because of incompatibility with source codec or output format
  * [2813] fix initialization of chapter list when editing queued job Chapter titles the user entered were lost when editing a queued job
  * [2814] fix a Gtk-CRITICAL error when editing chapter names
  * [2815] dvdnav: read error recovery - patch libdvdnav seek to guarantee the position will move forward when making a seek request to a position that is after the current position - when a read error is detected, seek forward and retry
* Sat Sep  5 2009 pascal.bleser@opensuse.org
- new package
